"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractRouter = void 0;
const lambda_router_1 = require("lambda-router");
class AbstractRouter {
    constructor(routerParams) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        this.addResources = (resources) => {
            for (const resource of resources) {
                const { path } = resource;
                if (resource.get)
                    this.router.get(path, resource.get);
                if (resource.post)
                    this.router.post(path, resource.post);
                if (resource.put)
                    this.router.put(path, resource.put);
                if (resource.delete)
                    this.router.delete(path, resource.delete);
            }
        };
        this.route = (event, context) => {
            const response = this.router.route(event, context);
            if (this.tracingEnabled)
                this.logger.info(response);
            return response;
        };
        this.logRequest = (event, _context, _path, _method) => {
            if (this.tracingEnabled)
                this.logger.info(event);
        };
        this.router = lambda_router_1.Router({
            logger: (_a = routerParams === null || routerParams === void 0 ? void 0 : routerParams.logger) !== null && _a !== void 0 ? _a : console,
            extractPathParameters: (_b = routerParams === null || routerParams === void 0 ? void 0 : routerParams.extractPathParameters) !== null && _b !== void 0 ? _b : true,
            includeErrorStack: (_c = routerParams === null || routerParams === void 0 ? void 0 : routerParams.includeErrorStack) !== null && _c !== void 0 ? _c : false,
            cors: (_d = routerParams === null || routerParams === void 0 ? void 0 : routerParams.cors) !== null && _d !== void 0 ? _d : false,
            parseBody: (_e = routerParams === null || routerParams === void 0 ? void 0 : routerParams.parseBody) !== null && _e !== void 0 ? _e : true,
            decodeEvent: (_f = routerParams === null || routerParams === void 0 ? void 0 : routerParams.decodeEvent) !== null && _f !== void 0 ? _f : true,
            normalizeHeaders: (_g = routerParams === null || routerParams === void 0 ? void 0 : routerParams.normalizeHeaders) !== null && _g !== void 0 ? _g : true,
        });
        this.tracingEnabled = (_h = routerParams === null || routerParams === void 0 ? void 0 : routerParams.tracingEnabled) !== null && _h !== void 0 ? _h : true;
        this.logger = (_j = routerParams === null || routerParams === void 0 ? void 0 : routerParams.logger) !== null && _j !== void 0 ? _j : console;
        this.router.unknown(this.onUnknown);
        this.router.beforeRoute(this.obfuscateSecrets);
        this.router.beforeRoute(this.logRequest);
        this.router.beforeRoute(this.beforeRoute);
    }
    obfuscateSecrets(event, _context, _path, _method) {
        for (const header of Object.keys(event.headers)) {
            if (['authorization', 'x-api-key'].includes(header.toLowerCase())) {
                delete event.headers[header];
            }
        }
    }
}
exports.AbstractRouter = AbstractRouter;
